using System.Collections.ObjectModel;
using System.ComponentModel;
using PlayParsingException.Annotations;

namespace PlayParsingException
{
    public class ListProvider : ObservableCollection<RowItem>
    {
        public ListProvider() : base(new []
        {
            new RowItem { Salary = 100 }, 
            new RowItem { Salary = 200 }, 
        })
        {
            
        }
    }

    public class RowItem : INotifyPropertyChanged
    {
        private double salary;

        public double Salary
        {
            get { return salary; }
            set
            {
                if (value.Equals(salary)) return;
                salary = value;
                OnPropertyChanged("Salary");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}